# GuidMetadata

An object that provides a mapping from a guid to a human readable name. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**guid** | **str** | Unique identifier | [optional] 
**org_id** | **str, none_type** | The organisation id this guid is a member of. | [optional] 
**guid_type** | **str** | a string that specifies the collection associated with the guid. | [optional] 
**uri** | **str** | A uri to retreive the full guid object | [optional] 
**name** | **str** | A name for a guid for a that is human readble. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


